
# q-expansion of newform 261.8.a.f, downloaded from the LMFDB on 05 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 261
weight = 8
poly_data = [-9372051456, -1918315520, 2140673280, -87078400, -54569376, 870160, 405148, -1540, -1101, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[-220, -2, 1, 0, 0, 0, 0, 0, 0, 0], 1], [[-3444485260061884928, 16597748370097197824, -2646200770332802304, -483051475075637248, 31504181884307240, 3458619680601900, -103076032004426, -8345660914107, 106065729814, 6233754023], 28887852727485440], [[14639812064013832704, 4246062437777767168, -1391084221456402688, -294262699538736256, 9290593285513240, 2896029471775740, -3833350436422, -9378681547239, -28318524622, 9928619411], 28887852727485440], [[-12196121786340917760, 2555043448653251328, 1259202298393198080, -119902995079836416, -23940811222695720, 1613758833810060, 131449898257210, -7213453276739, -202929968510, 10050605791], 28887852727485440], [[-87991771973511936, -1181839239326081408, 109345818305756928, 44317753607161808, -754635423476092, -378712347825940, 346512500191, 1130304968382, 2118846149, -1115090686], 2888785272748544], [[-6024362669097751552, -2963080854763713792, 676694101034703744, 202403301843300224, -3114211793369680, -1954325366596860, -9695139250004, 6170330968231, 33150136896, -6391461179], 14443926363742720], [[-35122228381584483328, -16117387730934428160, 4242912928379252736, 713385462546273440, -39527617495754080, -6142243453483380, 103445582880744, 17293113920495, -81328131916, -15515011515], 28887852727485440], [[21117344040416350464, 10547925623654974848, -2437318385798339328, -421196007236235056, 21362682998069740, 3516133178356680, -50887218595707, -9952790479169, 32671902363, 9184429821], 14443926363742720]]

hecke_ring_character_values = None
aps_data = [[0, 1, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-18, 4, 0, 0, -1, 0, 0, 0, 0, 0], [105, -23, 0, -1, -1, -1, -1, 0, 1, -2], [-735, -18, 6, 2, -5, -2, 0, 3, 8, -5], [2087, 88, 0, -2, -7, 2, -9, -2, 8, -29], [1156, -229, 36, -1, -17, -21, -40, -16, 15, -13], [7523, -372, -36, 30, 20, -30, 15, 10, -20, -25], [-6233, 829, 76, -45, -71, 27, 75, 18, -63, 84], [24389, 0, 0, 0, 0, 0, 0, 0, 0, 0], [19927, 3547, 274, 55, 176, -129, -90, 13, -179, 56], [-36850, 1522, 120, 34, -280, 154, -408, 496, -70, -1038], [-93210, 3035, 612, -133, 309, 127, 270, 220, 87, -351], [143879, -88, -542, 204, 175, 456, -832, 425, -138, -129], [28552, 24697, 2762, 243, 14, -737, -81, -19, 87, -799], [-395955, 15606, -1448, 952, 2215, -452, -259, 630, -1810, 427], [-668959, 64757, -1564, -1753, -931, -489, -235, -1442, 2577, -2386], [190714, 22353, 540, -1647, 393, 541, 790, 3648, 205, 1043], [-267514, 5418, -9984, -546, -2342, -1346, -390, -556, 3890, -1308], [-342732, 50100, -7012, -112, 3446, -1152, 5670, -2330, -2752, 5056], [-257702, -16816, -1848, -640, 6478, -848, -964, 252, -6744, 48], [421816, 48839, 5834, -1743, -6972, 2165, 3595, -1715, 5461, -5517], [-348861, 103235, -6836, 353, -4377, 1313, -8301, 3710, 3119, -11562], [39448, 4791, -27172, 3331, -2815, -4481, -3120, -436, 13219, 7395], [501134, 95139, -40724, 3539, 5537, -1865, 5654, 5440, 6655, 14173], [-342382, -69744, 5752, 1736, 5334, 8664, 24720, -2652, -12512, 16804], [2161236, -38294, -6412, 1854, -33180, 14470, -20474, -562, -4482, -28834], [1330225, -276823, -4480, -4681, 4479, -2041, -19461, -15280, 3641, -2542], [163616, -117894, -7944, 3570, 11299, -11358, 25330, -10272, -11226, -13196], [-367572, -42272, -43512, -8652, -16388, -7572, -18098, 11184, -528, -47494], [-7637659, -6262, -14196, -24304, 13058, 23220, 26041, -16610, -15870, 4207], [1570473, -760222, -12044, -11104, -9834, -2268, 42525, -24234, 18930, -16629], [14629868, -372758, -44000, -3306, -46052, 13110, -49262, -59744, 41346, -12136], [11203103, -606899, -12284, -7605, -52923, 1763, -39425, -30942, 53497, -32768], [4965809, -11438, 71224, -17724, -18707, 13864, 66625, 2102, 53362, -50597], [12241123, 588207, -91224, 8977, 70061, 17025, 28005, 33308, 14719, 10986], [-235774, -1369625, -159364, 759, -80463, 9099, -113178, -90412, 64651, -27427], [18106848, 202744, -90514, 8150, -10247, -15506, 58691, -65689, -15154, -2550], [-19764594, -501564, -154564, 53780, 35630, -37060, -56516, -17870, 1088, -92442], [17981650, 43386, 152232, 31074, 172038, -35830, 100656, 166376, -93998, 193970], [-25502768, -1996760, -48148, -3708, 12626, -8604, -48290, -6330, -2396, 40316], [8560512, 2513290, -90808, 31154, -39767, -70222, -16810, -64732, 69254, 108468], [-42892621, 2367782, 125868, -53912, -130306, 74756, -34725, -106386, 19646, -59951], [-52162092, -2227265, 58732, -2453, -22783, -27881, 113864, 3804, 164707, -16765], [2119342, 1041496, 105184, 73760, 308540, -43984, -13292, 112472, -62264, -132628], [34205805, 3825657, 89208, -35361, 171335, 92687, 23495, -58372, -32759, 59930], [74229432, 4392356, 113774, 8546, 48801, 102954, 75675, 103855, -208910, 64566], [-6435118, 55146, 109940, -57374, -213288, 103890, -200188, -37106, 300214, -503704], [-68356868, -3755180, 198580, 36336, 442534, 42640, -187002, -159434, -74288, -98496], [-17038316, -325149, -61476, -205689, 87809, -158685, 45700, -275000, 41063, 170639], [42830405, -1207151, -649916, 110915, -229174, 46507, -278897, -250130, -2971, -349884], [13722027, -8941097, 335388, 18117, 134939, 67493, 319395, -87478, -224413, 537694], [42153915, -6862443, 527028, -84797, -66538, 140147, -70375, 466334, 92249, -485178], [-76891758, 6210102, -192938, 33528, 351531, 119232, 273765, 379963, 35468, -91894], [-92567724, -219193, 49676, -71585, 134072, -73925, 123120, 23272, -223169, -58509], [59804453, 2620689, 517582, 276701, -118400, -179787, 184750, -35637, -165161, -263816], [-77147528, -860387, 653948, -385327, 243749, 111237, 229260, 231916, -218999, 115349], [-34747323, -7317837, -178458, -52345, 190258, 53895, 504910, 169823, -651927, 358038], [-279729990, -4911224, 263296, -22904, 97476, 178824, 84776, 194096, 242904, -90880], [136868535, -5817, 130492, -76875, -497220, -131, -534195, -696322, 898275, -665500], [-47357721, 1773155, 229948, 128953, -37453, -311575, -462049, -856662, 444055, 428606], [199229088, 14130518, -346800, -362638, -165638, 108578, -5906, -608888, 732222, -1252936], [200302633, -12432016, -995966, -73728, -869193, 16340, 11954, 278601, 317462, -8419], [-156248101, -26847394, 687788, 166416, 102838, -114420, 154435, 203054, -421258, -132927], [101958382, 1078953, 544036, -96163, -332072, -159751, 904378, 339360, 597313, -221469], [157076132, -18799999, 1260612, -291131, 912317, -236071, 426036, -391552, 194389, -40099], [-182988034, -591190, 1378142, -214596, 1532003, -624412, 901485, 1220303, -1003256, 167778], [132753830, 7723865, -897508, -79879, 600305, -328923, 177398, 998396, 623805, -153681], [-179861228, 8996724, 656516, 468464, -1246162, -616944, -600426, -639622, 1223048, 149452], [-40955361, -34891084, 1734016, -103598, -100709, 449094, 482815, -95714, -762676, 944271], [-84566018, -14522340, -22800, 41372, -1635844, 217196, -248808, -1929948, 1150660, -1470160], [340652480, -11267269, -344650, 237697, -1570454, 392261, 1434505, 696995, 399189, 200811], [-205045709, 26481432, 2006636, 118546, -820584, -55274, -121365, -1372130, 1471832, 929475], [147533646, 33798590, -1841016, 396650, 959829, -1010686, -972644, 380332, -452806, -446302], [432259071, -1996916, 544372, 324030, 440832, 1056594, 961495, 1135190, -927628, 2148627], [114541185, 4306197, 996040, 182339, 2097171, -335021, 199755, 1972272, -1862931, 2587246], [675611132, -7862472, -1082216, -733452, -1637294, -397796, 116190, -996848, -360792, -2329094], [391988232, 9360688, 1582528, -1051608, 146155, 379760, 1261114, -688076, -2108924, 2214470], [-213769295, 43664525, 630276, 836831, 2737714, -396105, -477825, 503690, -2615847, 1347924], [-30433542, 7682232, -2509688, -481120, -1154948, -582048, -116940, -2725284, 1211552, -1824968], [-534850554, 2270992, -5770916, 1115048, -964154, 1435568, -1228280, 2947770, -3055812, -584034], [1232416902, -41716935, -3070636, 6521, 395289, 47909, -1638850, -324852, 297573, 1146839], [-287971323, 54133859, 612532, -463939, -1115197, -518395, 520125, -2481006, -43113, -1221552], [405893450, -14803640, 933976, 703160, -886542, -101272, 1896724, 28844, -1264288, -1229520], [905120859, -3172555, -7700548, 441931, -72107, -1367389, -1109685, -352694, -669783, -211452], [-268843955, -18247282, -357972, 650012, -4317662, -801024, -2114475, -894006, 128062, -1808693], [212065942, -42300756, -4615920, 471036, -1403472, 2524, -2579040, 754112, 2373412, -4455812], [647483166, 45494744, 3191360, -517808, 926920, -281856, 359860, -473668, 2191648, -3653624], [-46656632, -52595494, -853168, 1654086, 269690, 456726, 747870, -1720912, -684246, 3398100], [494299505, 71396365, -1197716, -347625, 4562169, 49207, 3471297, 3022138, -641959, 2856958], [484543425, 5042564, -1558994, -2231472, -5047619, -121884, -1789968, -4979801, 806774, 858381], [846083785, 45079931, 1609450, 886267, 149172, 3157883, 2875620, 847185, -3205235, 1588782], [742767577, 127840173, -7561472, 22539, -3856913, -1028133, -5965309, -4095916, 3765709, -3846646], [1203215563, -34906432, 1549370, 2330916, 3204427, -326064, -754200, 824445, -3402554, 2508827], [34477037, -53219265, -5286012, -745151, -5470237, 1239881, -4942815, -4062026, -925981, -5236812], [1019713457, 18596971, -4130422, -775893, 1862100, 353835, 595284, 179609, -461059, -4232570], [522260807, -20756174, 8181048, -358304, 9997859, -2085428, 5687455, 3677254, -3826902, -844531], [393338672, 142418711, -1727428, 2617127, 7826182, -961181, 324880, -525908, -2512305, 7040647], [-277174608, 41268818, 85424, -758430, -1446906, 504026, -1464180, 4401456, 3833482, -342122], [-10576332, -6085974, 3430280, 1534998, 2201100, -4255162, -3971790, -3943396, -3305958, -692180], [1331307261, 44231467, -1444456, -2758623, -1714527, 1130121, 4628259, -5867336, 1344995, 1543540], [462320262, 86733762, 14870808, 688898, 784110, 4197786, -1575628, 4381548, 782546, -10455502], [282507070, 4160658, -10243302, -3076672, -2229067, -1975528, -5277, -218307, 9654892, -3956770], [-933360570, 17755150, -15257904, -2032474, 2080890, -5173218, -647800, -4359140, 4494534, 3309770], [848280194, 2142346, 5011640, 1086206, 5044966, -2588498, -5425630, 4301036, -2178030, -5972444], [1621232968, 48642117, 3938836, 2466273, 2718289, -2018443, -261712, -1397636, 6141345, 3040233], [71423455, -137719875, -1357012, 1805507, -644027, -1644709, -7079685, 3450774, -5452863, -11643328], [-1090310838, -14606241, -8265812, 5653827, 13476270, -282425, 702854, 2295584, -6376929, 8830845], [1567833844, -17282829, 5577734, -5567119, -2927322, 4113413, 1888925, 4483795, -4134443, 362383], [109849104, -211281825, 8064548, 279355, 10647557, 6246503, 8821920, 7788768, -4528573, 5715687], [-172963637, 6353073, -9009098, 4941577, 8608768, -5186871, -8992408, 3826015, 2424031, -7207246], [-342398328, -101352524, -4019120, -2668004, -3073779, -2672380, 5047814, -4961032, 4866840, 7286002], [-1738129820, -37191178, 5489104, -3298654, -10829760, 2014898, -4245622, -11692792, 4954750, -13097660], [3073336368, 127261670, 8713646, 4027060, -7314481, -7109084, -5478625, -34729, 3294604, -2074356], [-392198362, -277215094, -7889716, 3531034, 7758520, -3939206, 2639040, -8708398, 318686, 11289000], [1322154772, 68975375, 6837100, 1589931, -7561573, -4356217, 8163700, 331924, 10810171, -4646073], [2507267039, 391212873, -9297552, -884885, -2784905, -1895773, 453161, -2995756, 214137, 1216664], [2321437943, 4874717, -13594820, 3042379, 14628681, -998765, 7617287, -758366, -7568927, 10359096], [-291678230, 117825075, 1102460, -209605, 1511953, -2792225, -192126, 1865028, 260367, 10997917], [-698164258, -22723232, 11663558, -3417222, 3529909, 1451962, -4489355, -14102869, -5029114, 20399684], [-111094938, 116382578, 27946088, 1326018, 13639378, 5410490, 12153300, 1194156, -7256990, 18060658], [1250516165, -263556599, -25081116, 4942467, -2524042, -1828421, -16253885, -611570, -78323, 1848360], [-1806098880, -11263970, 15858168, -5226030, -25208686, 2967714, -4591598, -9364188, 18243246, -11897760], [-573789106, -23915200, 9276656, 4283108, 5912012, -3528836, -2182074, -2159824, -7127960, 19369970], [4884898530, -147694130, 12888504, 281354, 9963330, -2111542, 5160670, -8557520, 4645646, -7421000], [-2908152361, -99414694, 1369448, -3169624, 6165813, 4945220, 9462115, 10590154, -16781358, -9819307], [2632971345, 165501824, 25548048, 1086506, 13297037, -5141194, 15036365, -2280190, -16161144, 20295737], [1564560230, 360062550, -12258028, 9022582, -7502376, 2188422, -5900800, -3807690, 3913042, -1102896], [-2361768015, -344808686, 4648964, 95608, -27980630, 8901260, -11248351, 11553666, -562390, -12740469], [1918479626, 467951814, -10462400, 1035846, 2060012, -11438642, -4759792, -14988500, 918446, 403506], [2845299500, -173386106, 14380794, -589816, 22157821, 10401944, 11993465, 15784733, 3887152, 6572596], [-3421581081, -315975596, 6573412, -11515522, -14626336, 9811362, 2629987, -1551006, -6155172, -16550909], [-1023249859, -277700384, 35030916, -2159546, 6419048, -1795934, 7636965, -7256886, 1093504, 1226013], [-3164440438, -314718849, -9918868, 3273575, 1444187, 6265515, 8915414, 3336692, 11914419, -3636211], [877106234, -12066852, 60787152, 11432916, 9117416, -940780, 9877860, 25361812, -7819900, 10403636], [-4399484446, 479688177, 12336892, 8140345, 2745021, 8794405, 12346610, 3071196, -13460419, 3078731], [1704461160, -89378681, -5143412, 3877515, 3246985, -9190521, 14070300, -27851792, 416915, -337181], [-1856629022, 90872606, 23001764, 1682310, 11356744, 3214518, 9739044, -16832050, 7722170, 9796908], [-2507474214, 728901047, 9250900, 2523135, 8044575, 7553507, -6949306, 4245624, -6885077, 4759185], [2109913626, 363769956, -25372576, -5674476, -35833494, 14514916, 9925220, -9323328, 4032212, -7847704], [1224210861, -457156789, 14551424, 8765977, 9898989, -559871, -4944545, 24164704, -15899853, 24660864], [7619081329, 322522008, -35054352, 5784442, -10446825, -12245050, 3536725, 8697462, -5204832, -10336115], [2202153645, 102803626, -58970532, 1864368, 2635498, -5558348, -11105607, 4850518, 20818002, -3382665], [-25026598, -270584804, -26273670, 15170450, 20235155, -403646, 22692523, 10292333, -11897794, -3694560], [-6304817880, 282968015, 3010108, 1308771, -5688353, -9525873, 6982800, -23248088, 8757331, -4343193], [728196810, -626987795, 54058570, -6385469, -11146858, 3898903, -3956895, -6413851, -9865589, -14829293], [5174766338, -269839336, -54697824, 2844984, 8757964, -6179672, -8151024, 27834848, -29593840, -8010184], [316446018, -1136366615, 52991460, -11406403, -18317726, -6016407, -1018930, -16055196, 18933185, -10561773], [2371218163, 29184080, -24857650, -640872, 14215673, 9949908, 22467970, 40469327, -29265670, -1591897], [1388188840, -500668944, -54031524, 7807996, 12516098, -13778676, -8023698, -11694142, 6722132, 1219448], [5318183883, -343886358, -2660648, -1457256, -20530319, -14602924, 5530107, 23907506, 34330658, -43015883], [-706953558, -170757610, 14005216, -16763402, -7658558, 13239054, 4918460, 26087348, 13253974, 9226902], [12642949803, 577425439, -75938128, 1117825, -3886939, 724257, 9286045, -24637600, -6914897, -7348610], [7396181053, -703461217, 4559998, 12446235, 51110250, 9319755, 1540282, 37741115, -25335811, 6070314], [4222505527, -66682086, 86522020, 630404, -2992082, -5334672, -691761, -12202978, -25506102, 20065889], [-2615280521, -345933311, -14188806, -2369355, 9474538, -9738283, -4837050, -42897303, 41516363, -24972142], [781953518, -123852058, 43160004, -14433378, 3082444, -18977970, 32132900, 24399946, -4748438, 4471624], [-9709299134, -449467576, -30151888, 1055384, 9554188, -32535208, 5427440, 6613216, -31160216, 16389128], [-4673475790, 212636094, 72624696, -3366034, 36072602, 12309974, 27544724, -568348, 29202718, -463626], [-5358739948, -584307002, -14278968, -21896698, -20597451, -4400090, 19763410, -71168064, 2289642, 9113144], [222754327, 53726042, -8154290, 1477018, -12532177, 2275022, -66291214, -26756697, 48079228, -1490439], [1168414783, -30029777, -105149524, 8237013, -9441368, -5601683, -8484583, -15561638, 28571027, 29192340], [7598639212, 154375523, 12120214, 32350097, 7798062, 4970373, -13451515, 5608787, -35482491, 31525751], [-1306238133, 194894, 75515828, 6186272, 25701730, -42773044, 9978675, -25442826, 24392638, 50537545], [-3908152662, 104587189, 5712612, 11755441, 48047806, -9100067, -4567502, 52894504, -9339787, 41337783], [-1069141274, -592838315, 107108938, -8952381, 79487930, -890265, 38502741, 43830133, -13098437, -9979769], [5292484220, 678162286, 34035204, 19132466, 5288756, -5194486, 32917070, 26661690, 5268890, 49447166], [-2338107516, -171044558, -34203152, -17084810, -49342052, 37439702, -26269890, -24237288, 16574914, -3112244], [-3250172914, -1063397189, 44066796, 22277663, -42687098, 23551635, -7108490, 67213400, -21237461, 2956897], [160320392, -475871898, 138515616, 6213626, 9853344, -2402822, 31147878, 586312, 34661422, 31048712], [-4476020863, -465928705, -45933784, 5829365, 67133989, -11063299, 45296835, 52453176, -31731001, 98781384], [-1533784754, -1412248250, 74421800, -18122902, -50747141, 504290, -36931780, -30174988, 1854346, -16997926], [-18477614498, -350737844, 31051988, 14222172, 27252182, 31092292, 12833780, 3786798, -35692400, -5042038], [-4125477398, -633554910, -49178344, 3740370, -13731390, -19015718, -11955732, -86901296, -43574414, 80669238], [10125203399, -1030132057, 44524140, 486437, 15227387, -11592875, 35711395, -22540106, -30567525, 121369602], [-17605258894, 898337804, -51093856, 20681908, -68602460, -11040652, 22263220, -39907116, 75556852, 42717060], [5986823352, -1484915898, 10957344, 5638118, 34333354, 30605294, 70324620, -3954760, -19503714, 3974274], [12757475078, -302331673, 78653652, -5455289, 63043603, -10691557, 20174850, 15640120, -41622213, -11672187], [-23789394932, -154060537, 9981898, -9338247, -31389220, 18537933, 33074791, 9042477, 7826309, -60771577], [-678574422, 1421325278, 13047400, 7437478, -45617058, 27858654, 25588080, -8091832, -10716906, 4121702], [-21841196208, 1734759663, -14384814, 18927121, 106378752, 6653173, -32771753, 26972185, -70478651, 63941619], [5798300244, -168130000, -30849494, 36280226, -64922621, 31490010, -5391715, 8556885, -24921822, 12211554], [-6649608834, -430862486, -35803544, -3921118, -46921222, 2138122, 36905744, -5327924, -5952150, 62285886], [3256127052, 1738008797, 35614484, -5174067, 52425198, -2320991, 94910456, -2533788, -37265467, 59204853], [674807054, 185622194, -16048360, -28660754, 32702150, -18660546, 19852694, 20350720, 11184962, 23565748], [-13743474380, -1186065976, 18660560, 10674896, -10896191, -33372184, -46427010, -30251768, -32022452, -76541986], [-21801795136, 185222303, 13263980, 10747971, -42652389, -48983441, -89104208, -25775864, -10935309, -13788313], [-15116738617, 1612323016, 18104868, -13561622, -82712916, -17244562, -12059417, -63673994, 33319760, -53049761], [603053484, 638938419, 139119244, 34395255, 54865539, -54582701, 1738960, 40685212, 33774319, 11993959], [1293819377, 981887705, -86977320, -2112337, -61344181, -35924625, -45292545, 11105472, 4482081, -51813586], [-16034399753, 1043118261, 59278084, 10735947, -11770014, -10816437, -41234723, 80823606, -32847415, 98828202], [-4440036438, 1215102458, 136217830, 45183324, 134245591, 4272628, 36494813, -5855645, -13222720, -20522994], [16414951013, 903834664, 117272586, -31698280, -49270261, -6316100, 66204170, 41589029, -3457706, 86753409], [4471136584, -827936668, 184576056, 17831944, 64632150, -34882304, -15407590, 61886536, -11047604, 29260290], [6714692459, -1107191956, 32628212, 7642486, 154551304, 25918810, 104194971, 39124406, -59912412, -5953345], [-18620081518, 687377548, -7215216, 1988140, 23397660, 27658716, -87280072, -24801028, -57709244, 53983432], [-25017169816, -623788888, -136695088, 3374028, 95144942, 43561524, -71802350, -35159132, -78381456, -10754318], [12476708602, -637521562, 20580808, -8238658, -82288138, 13231350, -64661000, 14097536, -50449986, -68905522], [3838849747, 3099556565, -51811532, 24746323, 10145860, -20414509, -63092083, 56750158, -69377359, -4960342], [-7054320730, -1217165880, -80187104, -8719916, -24640120, 74697052, 42639962, 92495812, -5632520, -65485230], [-39115353554, 1524386639, 151164292, -22534153, -1301735, -16096197, 46619970, 1437568, -40746957, 5202685], [-914300361, 225732841, 43517364, 14197887, 78844553, 15518967, -26366205, 120616374, -113172139, -22001852], [-45735745304, 1048484079, 64020804, -20887101, 57108849, -27647217, -28122332, -26498412, 4122979, -21562065], [7887655800, 787618741, 65976420, 35168969, 193206595, -38597523, 66356000, -38167412, -17297359, -17924255], [21009694767, 444579388, 40946868, -10520338, 94997792, 65996034, -38416105, 155327022, -76543900, -59852053], [8707592516, 1483848032, -133484192, -19361272, -158049047, -27016256, 23588622, -88171568, 180696020, -59526690], [-2911561370, 3384631093, -101358270, -432597, -15698514, 718287, 18323625, -88922527, 34434243, 13682711], [5621312242, 520273908, -106631204, -84036380, -125360886, -26711668, -129719100, -171570562, 139571832, -43043086], [-19922527592, 1296612263, -98040916, -2640929, -52996954, -46592309, -99110740, -45430136, 81084375, -138469889], [17705459585, -1645089888, -25873762, -1987332, -156636859, -64200480, -6944800, -94481161, 75568858, -25006839], [-9814253480, -526831745, 95420564, 33701083, 49880537, 60897255, -5440200, 100274328, 50011123, 36091719], [-64752434718, 1413614616, 126997744, 48860064, 51941952, 9088368, 82153980, -9547288, 2501928, 88049732], [-25185727569, -2375158007, -220049874, -1586111, -129082284, -53773711, -198388016, -77370973, -35624593, 87019454], [-20151285441, 1051091270, -110795378, -28283770, 57893751, -3819126, 108158714, 92268039, 36367776, -71431555], [-13768724197, 524635234, 106803164, -18980364, -43996526, -41792992, 120257355, 86706966, 3528138, -62556491], [-7172003988, 100007517, 222851732, -70417387, -166408604, 5609097, -34240320, -36638952, -20039307, -95574719], [13688665944, -570996644, 36712232, -29368780, -57971548, -106918556, -154652468, -95811140, 28601380, 73976084], [278596844, -2568044286, -10801128, 21271510, 8476412, 97974, 105657790, -116580700, 77813602, 147049152], [26404105184, 1407879622, 105149040, 78975630, -196229174, -52907002, -52007336, 58345252, 139512086, -4841286], [-36082410912, 2100940920, -120450632, -64551068, -196082644, 2749852, 106231066, -157416176, 62693568, 128757814], [-19148710688, 2028680367, -345131540, -2367885, -66336545, -68225393, -114132240, -171934096, 129271915, -14763105], [38237304979, -265253879, 307834224, -24156133, 98244347, -8224365, 234629185, -25750976, 31040665, 192507572], [-70025605734, 1032902696, 146854568, 15939096, 70656212, 37348968, -57114800, 131259604, -166159104, -210699388], [59872073658, -3155101257, -11388766, -31587995, 153177844, -41035327, -17255191, 85115705, -149688755, 142742833], [-10704919742, 2957803830, 7708472, -5937822, -139442838, 12386690, -89481898, -181374652, -690498, -274607052], [34020363568, 351798400, 38084928, -7652996, -185864388, 70646964, -319590, 137196884, -105813992, 80371882], [51090040038, 3932390588, -183332624, -8676556, 13082746, -89797212, 47864392, -6200280, 8123268, 29533604], [32864804753, -387040710, -133095692, -31173232, -86260342, 56281412, 130364185, -107476630, 48172290, 110634003], [-32719415576, -2880373461, -407634202, 51111089, -170564066, -75404459, -38403335, 26571419, 227061373, 36839027], [3366148311, -1025680543, -32198024, -29154989, 90392587, 66562123, 53969905, 180224704, 25050681, -46954468], [9864700750, -1890115558, 397403504, -16079758, 125657984, 125938554, 67299148, 193738316, -106110254, -57306886], [45686589572, 603591262, -73550168, -66830282, -196432450, 228713870, 130238480, 70543868, -88520258, -39513950], [36335121263, 757955108, 94177108, -47076418, -72539880, -5117310, 181447515, -112700678, 63870748, 70276995], [12779293350, -2072238552, 109532432, 19288448, 224876198, -54700528, -220695240, 46634480, -80133960, 162529208], [46569859148, -4079320366, 73881116, 42046470, -127533356, -70108866, -209500906, -143329818, 156313910, -21640786], [-10184568579, -2250586706, 47423388, 23303380, -237757570, 19480776, 18175329, -113348418, -34145642, 307455179], [21949957616, -4615305299, -135939068, 20738665, 161341201, 30608509, 118113120, -194182516, -125978759, 62929841], [6052432594, -1676266405, -198868188, -91509941, -22708451, 150765503, -164618690, 72115208, 45229223, -329242731], [-10584226843, 1212144033, -50733160, 108092935, 114376807, -79228313, -190971545, 181195256, 18525297, 59954102], [3564305087, 268325919, -138740338, -42307529, -183143862, -205207105, -38109980, -123458741, -14811163, 214594488], [3211301123, -763640178, -229027678, 30954026, -99561751, -47899122, -4420008, -163313503, 214591540, -70781595], [25689117610, 1950882114, -188541492, -40624886, 293053712, -33942582, 38592700, -119741118, -25217962, 385861732], [61108073368, 2838562620, -387368580, 60168776, -36104794, -92584088, -59326602, 61352882, 68961248, -281214548], [-45109884518, 3146841980, 373234616, -85853316, 112236762, -107240612, -32056580, -150996908, 57329668, 79418212], [-7835109302, 4238609822, 224020600, -123065282, 114143786, 90456134, 215786204, 13872820, 3081038, 201390558], [-15479182280, 4757247646, 43965620, -102380838, -159656568, 20395618, -133217750, -95025750, 93203290, -465716638], [29477441165, -1791076951, 92551740, -34622485, -405498607, 82224555, -26168731, -77883602, 90756477, -148407678], [-47621873999, -315587715, -90293004, 71906671, -69485131, 69694015, -116161835, 31182730, 118236673, -271147766], [30819296420, -1174801142, 79785156, -37437930, -28297432, 204928462, 60001090, 263597962, -138673322, -160545562], [-21189304922, 5947961783, -71988082, 116096921, 208345082, 5084181, 98345011, 322580431, -191362223, 154704825], [-78458646216, -5240147833, 180656996, -201907149, 115028763, 17531487, -1097732, -284157676, -3260301, -161456297], [100872351492, -3075505531, -61435628, -23231547, 86924228, 39854153, 163454700, 397160912, 15576765, 158416213], [7791345449, 4601688921, 123068074, -76038951, 224403026, 34553969, 163435656, 240108577, -153979269, -101304072], [5066950338, 262379368, 273156904, -47836136, -53345894, 121125688, -62184660, 155186596, -112059448, 103253856], [32702026978, -1868180949, 272395356, -34129805, 115305353, -87875481, 134919466, -268102404, -542769, 308119765], [-53044894010, -4656573676, -168908664, -22257192, 67431444, -118817568, 269149390, 116856216, -229218244, 502971734], [39465047730, 2374149313, 367564412, -354135, 288246779, 59078117, 45758110, 137799968, 120706509, -197528221], [48548245686, 344087572, -81134254, 34158442, -24018521, -77811318, -73501213, -32367103, 134966254, -44235060], [44708447606, 6356999878, -123387752, -35791842, -103626342, 126840374, -56868208, -180659968, 33530590, 219075910], [-102810547457, 529842197, 61088964, 162262227, -8766578, -153860285, -90829551, -88935134, 178591697, -98189094], [158725394103, -4717459654, 98868316, 4203108, -474051758, 87130272, -97081393, -156191018, 113504722, -557951815], [48910558127, -1534571186, 182133014, -91670906, -292409361, -43363030, 264170742, 269059907, 141369432, -135155395], [38742293434, 659289846, -172192104, 101565406, 133057694, -74966154, -214420240, 88007712, 129861038, 186387494], [80360696930, 5240855273, -4997164, -5762143, 266625661, -185561395, 41118594, -458506820, 97295549, 456196403], [-17310493940, -4395644395, 371577652, -73124303, -139879003, 25654213, 173148712, 13552972, -253592287, -156416095], [13100460917, 953541270, -577396230, -98621370, 36388777, 16083554, -389177810, -287543595, 103691652, 87075067], [61397437084, -986493282, -334562584, -23517038, -612432364, -122898334, -259041010, -20265620, 125279694, -125038284], [-16145001350, -10349521847, -122414164, 75199657, 159210097, -146122027, 131061190, -453091060, 71659885, 166327167], [-56915455989, -1250937666, -871675980, -130069760, -358986566, -77428308, -477441669, -207232042, 279138974, -630261999], [-632769716, -7914698918, -387467304, 2112842, 42284425, -136330502, -224734318, -77239720, 176382462, -88360556], [-1886929623, -2842098000, 480955344, 187811306, 146154427, -157006810, 376398385, -92786842, -138590904, 34143577], [1563694076, -6586684078, 691438364, -207766706, 303820156, -102557082, 114433114, -171062930, 217129942, -60393422], [102184423075, 6429395661, 820719956, -26262013, -39780926, 84480995, -60060947, 174632938, -473486439, 22595150], [-36416551907, 1904157718, -340563844, -128434708, -658326594, 257074176, -100993735, -67828250, -29758866, -328997069], [-101986937904, 736233724, 378799024, -158833232, -406584710, 112234152, 113802338, -508982540, -110280892, 193069766], [30801741629, 8692888771, -210039238, -82491941, 107316616, 35696203, -35618904, 284021105, -251715139, -127684958], [115821832151, 5429429836, 502088868, -64891746, -376695400, 102337010, -450751609, -118183922, 422541668, -839758549], [61362559678, -2478446292, -158347776, -11678504, 60522971, -263605544, -79460080, 45233044, 270937680, -107435644], [9547631820, 373459194, -625579528, -45512826, -149814320, 16765446, 63215650, 172286676, 205080466, -364307580], [-22616297465, -8703272579, -355064572, 30973171, -52411455, 73567179, -430505005, 175760474, -292529111, -2977340], [-107804739030, -1443597054, 1043554828, 77799138, -167843844, -203830798, 272971512, -24851574, 215176774, 47062592], [34171190764, -3079647692, 550562988, -122918576, -559318654, -19080160, -219469410, 210116470, 303623952, -276200984], [-110479384282, 345690020, 380027816, 174083312, 48498804, -136561464, -78533910, 257333160, 43279580, -57537590], [-22524279294, -5715501910, 5730760, -45475118, -353770746, 81767706, -1655840, 135422508, -134037638, -209825826], [-19377093375, -437149978, -102276828, 5663556, -116658398, -47291688, 45597189, -276346562, -311698602, 127561727], [7794770255, 817664992, -283064476, 18521978, -674181156, 351832654, -376845885, 306825210, -114509704, -229219721], [30185754246, -235092813, 458343236, -925565, 221695195, 311435415, 121159314, 299380700, -212822777, -338716227], [71140833798, 2954465487, -1275441052, 113033351, -631903211, -126153269, -194796878, -127047352, -109013085, -610336427], [41524750359, 815345825, -383229888, 249906523, 415486927, 149312707, 284973285, -383006056, -171388591, 55563312], [-80122640389, -8264756601, -226836004, -103026219, -47269574, 195112173, -434975255, -225762202, 70064555, -190109944], [-28610225776, -199038884, 585325424, 324339140, 207627181, -379828340, -193844090, 215917996, -304373784, -18776394], [55767206973, -4895918925, 563749044, 7514933, 429845391, 79490221, 77117289, 653328614, -182676617, 253031600], [47511629723, -788791785, -625248244, 43884229, 37145614, 434850333, 13619521, 548653078, -12276565, 172305536], [225291270834, 5689216554, -300099842, 74606612, 267476343, 78729132, -175205135, -537911441, 45491536, -158043922], [4469158420, -1493420430, -576087904, 46478510, -569974118, 79975518, -296402794, -37951312, 261270418, 265115316], [84686690491, -4303653292, 201763632, 162929066, 626869551, 137559470, 865483355, 690488002, -716402140, 354904671], [78154057208, -13324899517, 1341838038, -31834327, -90918806, 103675117, 263552265, 194772051, 241981421, -46614941], [53990761383, 3468649704, 1222753952, -16894274, -542703751, 117596418, -558555953, -264663278, 335494000, -641914665], [-127290995431, 7634452941, 146591536, -29574581, 640447159, 197976523, 39317555, 373082024, -99613075, 683269494], [-247619008841, 2230696030, 534694132, -52681016, 318323914, 168108868, 221223735, 529285358, -364136722, -272463731], [-54706874602, 3033615113, -656814540, -253462303, 407567533, 217419693, 91346162, 467704848, -275954059, 46422623], [-144944156506, -5269973478, -641708040, -301425150, 477207162, 235362858, 1751512, -66218332, -476160390, 191150638], [18902189255, 8910294046, -1182157988, -136449000, -810346106, 20201540, -353596705, -511149826, 442287894, -56864571], [193029720613, -7622945410, 1297738326, 45527130, 688032267, 166353414, 85374188, 681066235, 53731752, -773569289], [41519347527, -15414020630, -796503212, 92567252, 325396406, -527141216, 247253375, 3284646, 442927514, 397014521], [-144453664996, -8263122035, -1117195964, 109801341, 61752144, -99556703, -61079284, -50463260, 185185133, -756904023], [138125295774, -6871557684, 582158538, 18505850, 1087512723, -102919398, 344286335, 451117837, -973583826, 666454956], [85854589241, 15767127448, -451639376, 396420754, -190976695, 13659966, -348224515, -70011774, 464380736, -681165935], [177459412375, -12461474503, -99644984, -258636421, -780224361, -13113501, 53371745, -395178704, 380785305, -900900556], [-156578511804, 1247959744, 533027616, -313116904, -362149369, -158209984, 211686850, 72130880, 125324412, 230072930], [32182196665, -3752880593, 1019970588, -14219999, 38775267, 442161865, 173972729, 563776294, -80289797, -589914340], [-58140350328, -640237723, -668527892, 138877841, -89238677, -162343659, 124162500, 390650396, 342228977, 388694893], [-23122120406, 4358815442, 1199334904, -509988622, 95380582, -203065910, 384982820, 148942820, 35513554, 512959322], [146833586535, 4337601033, -310831452, 127130879, 888687393, -177069337, 694729891, 1127628222, -3104963, 1002211468], [147246980109, 15205011879, 1162975512, 20796685, 499069101, 264298389, 125670419, 188084664, -575618249, 406169520], [179373995333, 7672218473, 392546148, -317009213, 650681268, 417423371, 537526095, 525879842, -490298019, 792066688], [179018459747, -9368763274, 1067932452, 328413208, -138249358, 3938468, -12318245, -8281514, -37271466, -482690263], [112951502338, -811352066, -831648452, 113575686, 598998488, -158522, 500532900, 91985070, 254450442, 72032348], [137558959658, -4230300233, -697540948, 24855011, -430415622, -129118857, -253925126, 4548216, 26087671, -136142999], [68964971088, 5808444845, -1590557724, -252837039, 17612349, 52695525, 104427980, -275653860, 431407473, 589129909], [92523611766, 5279125666, -1320384502, -21904928, -284791503, -355529768, -52835285, -772128147, 471819620, -566745578], [26946128320, 12563239049, 809128708, -296422855, -221952452, -70949011, -268994796, -118895824, 215533857, 52429441], [-122759357730, 2890224696, 948609568, -430021904, 689559360, 62230464, 443540580, 522151664, 340846024, -3113900], [32386185733, -11208627295, -1049883146, 351299109, 1115657116, -58029283, 164412202, -253875457, -211339217, 305128168], [-232599618441, -16893810745, 887311404, -254084715, -14738068, -443666755, -281757443, -21865458, 164592435, -560389180], [-166117193724, 5873271511, -1068906156, -284645877, -649397071, 180297223, 396505740, 96531368, 204043291, 218367979], [-122105127552, -24157745630, 39246012, -44526034, -467300184, -51392458, -847302270, -275817794, -394845610, -430534534], [-31025213178, -15638084092, 605474216, 61674512, 960947200, 176494424, 567368794, 1007957672, -1107154804, 1033780714], [125158551180, 1052044927, 332908158, -147042827, -36987814, -830303943, -181751263, -414438089, 898289969, -149106013], [-76298599764, 1361586792, -761223872, 104081912, 604779571, -148354672, 225789758, 206713296, 554795892, -869191266], [-181538569804, -5865183422, -407917048, 382346542, -1624944, -280320866, 834227370, 79048076, -298433806, 1537764556], [-72251091951, -3021447822, 165425000, 410528348, -287377891, -389669104, 474832517, -357396278, -279753142, 331312995], [151303558382, 779104612, -848055416, 260981336, 1763200828, -24864016, 369615470, -121767888, -351377748, 881688558], [-16164271511, 2485467202, -1369057548, -202741056, 229157174, 55405348, 241622525, 314734598, 384326098, -204314501], [-34632359901, -3701268250, 773891182, 63062798, 1517031059, 141340706, 495308150, 281058319, 251192376, 533075689], [109462682970, 12310044482, -528536272, 195249766, -469504202, -32168330, -38907758, -988813640, 590875282, 419752784], [298380749314, -4793597148, -1827039296, 247788140, -288797036, 159447692, 98394900, -97846032, 64627444, 553702544], [335621668720, 14532299512, 299846960, 63071708, -429776044, -37336652, -549402658, -744500932, 718847144, 394417798], [147763421664, -3327136418, -145102680, -552322214, -979480650, 246611066, 113565110, -668197412, -61466546, -1445195100], [155171336668, 7649223090, 931292512, 139094786, -173257834, 339664218, 377523228, 1278042544, -634169542, -139106842], [193675811690, -20866758015, 1938013796, -207530903, 343575797, -314606395, 241779202, -995658284, 173949373, 229630707], [-140139748890, -6832888952, -101746352, -665869712, -299457832, 91324032, 193226988, 152046788, 911154592, -242062600], [68713453794, -17128963971, 144799268, 187431853, -38693927, 364795481, -607915170, -263828492, 844938865, -363015677], [-34569207842, -9182134810, -504389856, -128648822, 793748218, 416268650, 335230410, -694153604, -532258050, -1010169032], [-232947660682, -3349732030, -831703208, 37444674, 124313318, 175080346, 1047816548, 621508328, -82945814, 588640310], [15815382963, 26700461008, 1411640022, 69963264, 1171689697, -433559876, 230421910, -367656661, -255835462, 370928807], [9440329834, -2986616555, -491051908, 120252725, -1107537131, -82908511, 574088950, -838714688, 1137066009, -519561481], [112134793855, 17368199926, -97917572, -257060264, 776727962, -84044940, 276689059, -1131484526, 143812438, 895500005], [-24318030882, -2162196607, 33333094, -105205109, 864126412, -987892977, -305309405, 377990419, -66621429, 162077727], [-190180122018, 3435183082, 1880223848, 416171690, 69219958, -101145582, 879405452, 479295104, -1096557702, 1534316766], [-159824125059, 2697008313, -607840780, -216980717, 49676717, 63978019, 443938145, 284012218, 957134109, -722498838], [-287309456070, 10190788716, -109978992, 223630860, -32996556, -99895876, -1030397368, 936244092, 259323236, -1082113960], [-160183673576, -8419752530, -1031573784, 36969426, -235311150, 854126882, -145820870, 442352860, -841140546, 821019600], [8475371685, -25784212347, -1756227100, 230601799, -520548623, -71087561, -278138387, -364271302, 711609793, -1142614070], [-380983382290, -9323745209, -1595621468, 464298399, -381623189, -201792205, -1235060930, -590617760, 22502627, -2318153199], [-338918993146, 1561677861, -909962204, 274306021, 368270577, -189358303, -70537650, 579229568, 651808025, -528202241], [114481853035, 9218580177, -384458, -579801239, -183665468, 487956041, 742437800, 787601575, -438313849, 819841642], [29267793351, 16966254761, 3595150168, -70153037, -136640829, 325681259, 89101805, -772878728, 873790833, -689252544], [235822074756, -14197230225, 638739004, 123866555, 1201312123, -49799961, 580044068, 457652156, -649270525, -574505361], [-124698376086, -8760266978, -819034684, -471235418, -1036230688, -305586042, -835386052, -966425458, 88826090, -1119128748], [-391573936306, 19250127124, 1446395168, -252497952, 462286195, 551953760, -85609760, 582865756, -270341208, -658222892], [126201506387, 24987963771, -194375876, -154711007, -345976554, -260937543, -549178635, -318300222, 151047063, -352589324], [-338760636936, 1527406145, -674301506, 471007, -177454680, 41894107, -893341063, 894442703, 49592347, -9021947], [-23764649788, 5361767738, -1765700372, -573833970, 191481232, 929027686, -303973730, 1192231434, -730452058, -100497798], [28746365779, 2033058634, 1503234642, -231245642, 1035353777, -30021238, 397654776, -242741143, -204567800, 2081638233], [-545104554886, 19547158475, -871082748, 216353387, 792041609, 179106831, 400825254, 669784700, -766205417, 865662633], [-388119453988, 15830065688, -617997640, -283480700, 143609938, 700658044, 279552302, 127417376, -735294192, -291407238], [67236171574, 9326287896, 995768564, 47943448, 2176293474, -835788272, -186380268, 1525929466, -1789725052, 460671562], [-96513276686, -11419548724, -561984280, -310045724, -1721220364, -864813308, -1066654540, -1121138364, 579185740, -1155444364], [-389242394240, -3277346954, 1824918602, -128726416, -991962319, 200422320, -412732755, 168319885, 271309912, -850928144], [166539180532, 27463490568, 1147990644, 157778748, 1681831506, -352242516, 603867530, 1580726282, -1260240132, 1368819596], [235038573431, -19257979663, 1572179720, 73613899, 46383935, -265830349, 482992781, -951082000, -888420687, 409831792], [157520728130, 13940702120, -1775260240, -584383136, -1564541804, 159869168, 289734460, -1305645384, -679231448, 568116276], [155798708315, 2205263515, -805784948, -318268271, -245590485, 780959617, -473409865, 748465618, 182390871, -1790560570], [6898692420, 24437491692, -709697936, 627056020, -624058863, -108048548, 491416446, -586845644, -407197192, -360120010], [216198087433, 400746726, -1702368500, -109898884, -1719642822, -30445744, 288254465, -778221494, 830155782, -1650963577], [-230040232355, 1101090617, 1678680850, 198474713, -936209162, 880684385, 118855280, 432312941, 353989555, -202643772], [-550717571170, 8581355599, -3047625324, -219825505, -213123033, -471147597, 449001906, -1197719772, -204696997, 1671545361], [229103904964, 34223039309, 978744596, 447234357, 1092204892, -342146231, 863091080, 268031972, 1373421165, -1510053043], [-422143020626, -21136352335, -1729129468, 237216021, -1141611108, 249200145, -1810267670, -1382167056, 2348342985, -1963737733], [-36243715140, 29044207900, -1030409040, -603998640, -115378890, -420905640, -660053870, 212317420, -30869780, 561325710], [-207187624188, 25452122867, 2382575148, 285929811, 790254424, 11471119, 413736748, -813039556, -235397773, 1153147423], [-200264482748, 43113220403, 3246359990, -622091919, -1756240982, 1191776485, -522480115, -443003005, 567634733, -2298745425], [-226071628460, -10686665265, 2362772292, 128880451, 2627591779, 709470287, 642724240, 1662083880, -834281109, 739161175], [584283093449, 4084286621, 1512035352, -508794445, 319922515, -168770893, 1360287695, 502568924, -557463275, 2589126310], [59644575109, 13614473715, -1887989248, 58263857, -1543980799, 150555881, -1040569105, -1046829848, 1203035491, -3306443024], [137471584985, 4133466538, 1992003380, 6172000, -1072984326, 197890196, -1529957415, 373822946, -526664446, -325329941], [-207327800975, -27224463606, -271399288, 339098716, 1635159631, -209886608, -364754459, -541379658, -104305166, 788062343], [-390790708442, 13089345864, 902768910, 92911258, 1247946041, 46614234, 1906535969, -671048705, -845795082, -888471812], [323544792997, -20213672504, -48274868, 588810950, -403557316, -1511073630, -923149695, 293120534, 1158989632, -2824653843], [162754564576, 18331935604, -1328018792, 548421496, -2106132404, -1134079296, -1917010250, -899395800, -76979580, 298839326], [-208263003999, -5414332376, 1920325888, -175061558, 1245701805, 137655878, -124578415, 1107767410, -2053287552, 368631325], [-187021306324, -15440314438, -1033639458, -23733840, -790654745, 808135968, 496140275, 136177871, 144562920, 440362500], [115492724337, -6952897170, -1084354674, -165849894, 396308959, 1059452278, -272106052, 1539744247, 444897792, -282994693], [-133718005403, 14431105895, 2309606918, -901604565, -1030295382, 598325595, 236097390, 230339543, 1085706213, -52271662], [-255449657712, -3341873753, 3839619948, -739507521, 723972130, -295100021, 860893284, -604872684, 569611439, 108365051], [-100299517378, -22424131856, -1241150008, 870066332, -364372896, -317752764, -1078238110, -1772115572, 1238826272, -2002860646], [-435059775452, -23799043956, -1832794864, 636339808, 3204479234, 32345912, 3298857890, 2242958556, -1720847164, 2039639694], [292112286170, -1252872802, 2051165508, -222696906, 2683234952, 772592902, 1498693180, 1580189830, -3439529702, 2263091772], [546476849054, 12560349280, 508231888, 22085632, 31256196, -237737936, -1319993760, -744716664, -1515895656, 787734376], [-57934830394, 17900849234, 1301016712, -53403030, 3310937634, 761788818, 2742709600, 888390120, -366004166, 416133514], [666676669976, -65544825272, -895149328, 5328844, 1473488964, -753172748, 544204678, -424078884, -775512656, 2451945294], [-122145443415, -8308461132, 3423096380, 849340122, 338071960, -444905898, 1946986821, -819033722, -24234340, -543784779], [-498292825977, -8618699385, 1112270412, -417299099, -938880618, 1462290973, 214641801, 852016970, 1102723827, -1455162748], [73307565093, -35505387278, -2174547928, 123038364, 784600317, 1235581488, 309586325, -371308618, -1812801422, 2086942647], [-44460996757, 743308699, 875325308, -880402815, 91830631, -660220015, -506496105, -1111952594, 2246345871, -1661924934], [-750106586526, 17481776634, -1850856536, -447033690, -493831881, -34897410, 559484128, 1083625804, -318948962, 288621378], [-116499700960, 18932484497, 3704776412, 474008077, -533131323, 1363577425, -326100480, -1305693216, 865489405, -1843303183], [88579987827, -8644471994, -2453474630, 196848074, -1580093343, -1051700722, -2867572964, -179195219, 1862606844, -3271391555], [-42827320104, 5150431494, -2457324696, 675400582, -2021124910, -1132559186, -2005060540, -1081670060, 1104340358, 346002110], [-553706484890, -32313378334, -4073095576, 274818058, -1432961314, -43241710, -2349097968, -1705826188, 1547989794, -1905954690], [-31850676771, 24401083262, -292318168, 491573656, 166066711, -715573460, -310034943, -928742942, 403862686, 1002195683], [400364812893, -15383313141, 3082524112, -625921807, -2312346671, 521322105, -1533727597, -53979640, 1150853555, -4033817564], [613934449925, -59813816947, 126489068, -333180089, 266231797, 402299015, 1120145465, -310163982, 675419841, -95603858], [-74174408532, 15835584235, -634698460, 329409327, -1477742235, 260550363, -626648612, -470449960, 555329439, 210314271], [-428958168120, 36609279396, 115646992, -961730376, 1576421596, -633749440, 658970630, -2182829580, 34520212, 1763364066], [-335261576933, -7549862197, 5327290410, 269301159, 2999785832, -299934817, 1712012590, 2594291737, -12756867, 2337993492], [179037497888, 7955262912, 4578549924, -128831132, 823148550, -1337459404, 1614818106, -1315601142, 1696523524, -117870364], [276798251716, -25861430000, -420439632, -1180621948, 141616838, -417043332, -2568661646, -804454692, -115535840, 632964482], [476205683232, -8479828431, -593172746, 79789831, 1359914420, 618067267, -1276549339, 2272027571, 349748611, -914332555], [-121196793774, -55323507464, -3075738544, 686233752, 1593179604, 989069560, 331117240, 555002216, -154771688, 2404775944], [-19589230256, 43118771374, 1754822440, -486991958, 1347694070, -676332550, 1404371102, 596795964, 872904582, -272446964], [189967637245, -50373746945, 3275219754, 261815303, -747764748, -96665465, 1781353640, 1080772313, 486847113, -955180106], [738638196113, 13139601900, -2877842318, -901837012, -3122362113, -993158288, -1924558190, -3090181951, 478081914, 1836153217], [-216344638697, -56865897409, -5896217284, -1425034611, -1598343298, -133217787, -303668095, -558628834, 1000230467, -924094272], [-202889341532, -18944228236, -3590257760, -150179116, 1305507067, -521702020, 1824416550, -94111680, 1710346832, 461648930], [631672587543, 4153790935, -2522310244, 831047749, 16602595, -336216187, 741789819, -991610706, -359616621, 441496850], [447906039452, -18376337660, -1016388496, -1042711224, -1023769570, 1024806256, -217001510, 1873896428, -2206982716, -2344837970], [350234241089, 2916901717, -3676548356, 270214183, -3176500895, -532220649, -2222922795, -686698750, 1078083097, -1650253270], [1012972346363, 26571969027, -311872726, 68043103, 576001380, -1306402089, 590495870, -1078940615, -1730682403, 1148814780]]
